Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(39)

Unified Diff: components/arc/arc_bridge_service.h

Issue 1701063003: Refactor ArcBridgeService detection and initialization to a separate class ArcServiceLauncher. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Rebase master Created 4 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/chrome_browser_chromeos.gypi ('k') | components/arc/arc_bridge_service_impl.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: components/arc/arc_bridge_service.h
diff --git a/components/arc/arc_bridge_service.h b/components/arc/arc_bridge_service.h
index 56179d0287cefcf5a19a29de2272b2342c9bd5ec..fea9b9eedc733b11928be52bab1f7b07fabbb5a6 100644
--- a/components/arc/arc_bridge_service.h
+++ b/components/arc/arc_bridge_service.h
@@ -131,10 +131,10 @@ class ArcBridgeService : public ArcBridgeHost {
// switch.
static bool GetEnabled(const base::CommandLine* command_line);
- // DetectAvailability() should be called once D-Bus is available. It will
- // call CheckArcAvailability() on the session_manager. This can only be
- // called on the thread that this class was created on.
- virtual void DetectAvailability() = 0;
+ // SetArcAvailability() should be called once CheckArcAvailability() on the
+ // session_manager is called. This can only be called on the thread that this
+ // class was created on.
+ virtual void SetArcAvailability(bool availability) = 0;
hidehiko 2016/02/22 08:08:40 ArcBridgeService::SetArcAbailability and ArcBridge
// HandleStartup() should be called upon profile startup. This will only
// launch an instance if the instance service is available and it is enabled.
« no previous file with comments | « chrome/chrome_browser_chromeos.gypi ('k') | components/arc/arc_bridge_service_impl.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698